.error-status {
  margin-top: 10px;
  padding: 10px;
  border-radius: 4px;
  transition: opacity 0.3s ease;
  background: #f2dede;
  color: #a94442;
  border: 1px solid #ebccd1;
}


/* Add this CSS for the spinner */
.spinner {
  border: 4px solid #f3f3f3;
  border-top: 4px solid #3498db;
  border-radius: 50%;
  width: 24px;
  height: 24px;
  animation: spin 1s linear infinite;
  /* margin: 10px auto; */

  /* Positioning to the left */
  margin: 10px 0 10px 10px; /* top, right, bottom, left */
  display: block; /* Ensures it behaves like a block-level element */
}

@keyframes spin {
  0% { transform: rotate(0deg); }
  100% { transform: rotate(360deg); }
}

.feedback:blank { display:none; }
